/**************************************************************************************************
* Project name: 
*     IR Reflect Click
* Company: 
*     (c) mikroElektronika, 2015
* Revision History:
*     15.06.2015. Initial release (DB & PT)
* Description:
*     IR reflect click carries a GP2S700HCP reflective photointerrupter. 
*     On this type of photointerrupter the infrared emitter and receiver are facing the same direction,
*     the infrared beam from the emitter gets bounced back to the receiver when an object is placed within the detecting range of
*     the sensor (optimal range is 3mm). IR reflect click communicates with the target board microcontroller through mikroBUS
*     AN and INT pins (an onboard potentiometer sets the Interrupt threshold). Its designed to use a 3.3V power supply only.
*     These sensors are used to detect an objects presence or motion, such as a piece of paper passing through a printer.
*     To avoid setting off false alarms, avoid exposing the sensor to other sources of infrared light
*     (which could come from an ordinary incandescent light bulb).
*     Also, black objects wont reflect infrared so the click wont detect them.
*     On the other hand, reflective metalic surfaces will trigger the sensor from a larger range.
*
* Test configuration:
*     MCU:             PIC18F45K22
*                      http://ww1.microchip.com/downloads/en/DeviceDoc/41412D.pdf
*     dev.board:       EasyPIC v7
*                      http://www.mikroe.com/easypic/
*     Oscillator:      HS-PLL 32.0000 MHz, 8.0000 MHz Crystal
*     SW:              mikroC PRO for PIC
*                      http://www.mikroe.com/mikroc/pic/
*     Hardware:        IR Reflect Click
*                      http://www.mikroe.com/click/ir-reflect/
* NOTES:
*     - Insert IR reflect Click in mikroBUS socket 1
*     - Turn ON USB UART switches (SW1.1 and SW2.1) and put jumpers on USB UART.
*     - For UART communication use USB UART port at 9600bps
**************************************************************************************************/

// IR Reflect module connections
sbit IRRef_In at RB0_bit;

unsigned int adc_result;
char txt;

void main(){

  ANSELA.B2 = 1;                    // Set RA2 pin as analog
  ANSELB.B0 = 0;                    // Set RB0 pin as digital
  TRISA.B2  = 1;                    // Set RA2 pin as input
  TRISB.B0  = 1;                    // Set RB0 pin as input

  UART1_Init(9600);                 // Initialize UART module at 9600 bps
  Delay_ms(100);                    // Wait for UART module to stabilize

  UART1_Write_Text("Start");        // Send Start to UART port
  UART1_Write(13);
  UART1_Write(10);

  ADC_Init();                       // ADC module initialization

  while(1){
     if (RB0_bit)                                       // If Interrupt is detected!!!
           {
           UART1_Write_Text("IR Reflection Detected");  // Send IR Reflect Detected to UART port
           UART1_Write(13);
           UART1_Write(10);
           }
        else
           {                                  // If there is no reflection
           UART1_Write_Text("No Reflection"); // Send No Interrupt to UART port
           UART1_Write(13);
           UART1_Write(10);
           }
     adc_result = ADC_Get_Sample(2);          // Get ADC value from RA2 pin
     WordToStr(adc_result, txt);              // Conversion to string
     UART1_Write_Text(txt);                   // Sending ADC data to UART
     UART1_Write(13);
     UART1_Write(10);
     Delay_ms(1000);                          // Delay 1000ms
  }
}